@@ -408,6 +408,7 @@ class CoreEnv(object):
     SKIP_TTY_CHECK = 'OVEHOSTED_CORE/skipTTYCheck'
     RE_DEPLOY = 'OVEHOSTED_CORE/additionalHostReDeployment'
     NODE_SETUP = 'OVEHOSTED_CORE/nodeSetup'
+    MISC_REACHED = 'OVEHOSTED_CORE/miscReached'
 
 
 @util.export
@@ -976,6 +977,7 @@ class Stages(object):
     VM_RUNNING = 'ohosted.vm.state.running'
     VM_SHUTDOWN = 'ohosted.vm.state.shutdown'
     BRIDGE_AVAILABLE = 'ohosted.network.bridge.available'
+    BRIDGE_DETECTED = 'ohosted.network.bridge.detected'
     LIBVIRT_CONFIGURED = 'ohosted.libvirt.configured'
     SAVE_CONFIG = 'ohosted.save.config'
     SSHD_START = 'ohosted.sshd.started'
